@@ -38,7 +38,7 @@ from .utils.eda import ts_plot, test_stationarity, ets_decomposition_plot, \
 from .utils.etl import log_power_transform, decompose, normalize, split_data
 
 
-def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True,
+def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezone=None,
                   time_interval='', forecast_period='', auto_load=True, auto_clean=False,
                   epochs=10, batch_size=256, score_type='rmse', non_seasonal_pdq=None,
                   seasonality=False, seasonal_period=12, seasonal_PDQ=None,
@@ -178,7 +178,7 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True,
 
     if auto_clean:
         print("Begin initial cleaning of the extract dataset...")
-        ts_df = clean_ts_data(ts_df, target, as_freq=freq)
+        ts_df = clean_ts_data(ts_df, target, timezone, as_freq=freq)
         new_key = f'{data_counter}) Clean'
         data_dict[new_key] = ts_df
         print(f"\n--> Cleaned data saved in data_dict[{new_key}], see head below:")
